@@ -7,6 +7,7 @@ use smallvec::SmallVec;
 use crate::composed::key::KeyDetails;
 use crate::composed::signed_key::{SignedPublicKey, SignedSecretKey};
 use crate::errors::Result;
+use crate::packet::KeyFlags;
 use crate::ser::Serialize;
 use crate::types::{PublicKeyTrait, SignedUser, SignedUserAttribute};
 use crate::{packet, ArmorOptions};
@@ -112,44 +113,58 @@ impl SignedKeyDetails {
     }
 
     pub fn as_unsigned(&self) -> KeyDetails {
-        let primary_user = self.users.iter().find(|u| u.is_primary()).map_or_else(
-            || self.users.first().expect("missing user ids"),
-            |user| user,
-        );
+        if let Some(primary_user) = self
+            .users
+            .iter()
+            .find(|u| u.is_primary())
+            .map_or_else(|| self.users.first(), Some)
+        {
+            let primary_sig = primary_user
+                .signatures
+                .first()
+                .expect("invalid primary user");
+            let keyflags = primary_sig.key_flags();
 
-        let primary_user_id = primary_user.id.clone();
-        let primary_sig = primary_user
-            .signatures
-            .first()
-            .expect("invalid primary user");
-        let keyflags = primary_sig.key_flags();
+            let preferred_symmetric_algorithms =
+                SmallVec::from_slice(primary_sig.preferred_symmetric_algs());
+            let preferred_hash_algorithms = SmallVec::from_slice(primary_sig.preferred_hash_algs());
+            let preferred_compression_algorithms =
+                SmallVec::from_slice(primary_sig.preferred_compression_algs());
+            let preferred_aead_algorithms = SmallVec::from_slice(primary_sig.preferred_aead_algs());
+            let revocation_key = primary_sig.revocation_key().cloned();
 
-        let preferred_symmetric_algorithms =
-            SmallVec::from_slice(primary_sig.preferred_symmetric_algs());
-        let preferred_hash_algorithms = SmallVec::from_slice(primary_sig.preferred_hash_algs());
-        let preferred_compression_algorithms =
-            SmallVec::from_slice(primary_sig.preferred_compression_algs());
-        let preferred_aead_algorithms = SmallVec::from_slice(primary_sig.preferred_aead_algs());
-        let revocation_key = primary_sig.revocation_key().cloned();
+            KeyDetails::new_direct(
+                self.users.iter().map(|u| u.id.clone()).collect(),
+                self.user_attributes
+                    .iter()
+                    .map(|a| a.attr.clone())
+                    .collect(),
+                keyflags,
+                preferred_symmetric_algorithms,
+                preferred_hash_algorithms,
+                preferred_compression_algorithms,
+                preferred_aead_algorithms,
+                revocation_key,
+            )
+        } else {
+            // We don't have metadata via a primary user id, so we return a very bare KeyDetails object
 
-        KeyDetails::new(
-            primary_user_id,
-            self.users
-                .iter()
-                .filter(|u| !u.is_primary())
-                .map(|u| u.id.clone())
-                .collect(),
-            self.user_attributes
-                .iter()
-                .map(|a| a.attr.clone())
-                .collect(),
-            keyflags,
-            preferred_symmetric_algorithms,
-            preferred_hash_algorithms,
-            preferred_compression_algorithms,
-            preferred_aead_algorithms,
-            revocation_key,
-        )
+            // TODO: we could check for information in a direct key signature and use that
+
+            KeyDetails::new_direct(
+                self.users.iter().map(|u| u.id.clone()).collect(),
+                self.user_attributes
+                    .iter()
+                    .map(|a| a.attr.clone())
+                    .collect(),
+                KeyFlags::default(),
+                vec![].into(),
+                vec![].into(),
+                vec![].into(),
+                vec![].into(),
+                None,
+            )
+        }
     }
 }
 
