@@ -19,23 +19,14 @@
     clippy::unwrap_used,
     rust_2018_idioms
 )]
-#![allow(clippy::missing_const_for_fn, clippy::use_self)]
+#![allow(
+    clippy::missing_const_for_fn,
+    clippy::use_self,
+    clippy::needless_borrows_for_generic_args
+)]
 // Enable backtraces for thiserror.
 #![cfg_attr(feature = "nightly", feature(error_generic_member_access))]
 
-#[macro_use]
-extern crate nom;
-#[macro_use]
-extern crate generic_array;
-#[macro_use]
-extern crate log;
-#[macro_use]
-extern crate derive_builder;
-#[macro_use]
-extern crate bitfield;
-#[macro_use]
-extern crate smallvec;
-
 #[cfg(test)]
 #[macro_use]
 extern crate pretty_assertions;
@@ -51,7 +42,6 @@ pub mod base64_decoder;
 pub mod base64_reader;
 pub mod composed;
 pub mod crypto;
-pub mod de;
 pub mod line_writer;
 pub mod normalize_lines;
 pub mod packet;
