@@ -4,11 +4,10 @@ use std::ops::{Range, RangeFrom, RangeTo};
 use std::{hash, io};
 
 use byteorder::{BigEndian, WriteBytesExt};
-use nom::branch::alt;
 use nom::bytes::streaming::take_while1;
 use nom::character::is_alphanumeric;
 use nom::character::streaming::line_ending;
-use nom::combinator::{eof, map};
+use nom::combinator::map;
 use nom::multi::many0;
 use nom::number::streaming::{be_u32, be_u8};
 use nom::sequence::preceded;
@@ -83,9 +82,7 @@ pub fn strip_leading_zeros(bytes: &[u8]) -> &[u8] {
 #[inline]
 pub fn strip_leading_zeros_vec(bytes: &mut Vec<u8>) {
     if let Some(offset) = bytes.iter_mut().position(|b| b != &0) {
-        for i in 0..offset {
-            bytes.remove(i);
-        }
+        bytes.drain(..offset);
     }
 }
 
@@ -113,35 +110,21 @@ pub(crate) fn packet_length(i: &[u8]) -> IResult<&[u8], usize> {
     }
 }
 
-/// Write packet length, including the prefix.
+/// Write packet length, including the prefix for lengths larger or equal than 8384.
 pub fn write_packet_length(len: usize, writer: &mut impl io::Write) -> errors::Result<()> {
-    if len < 8384 {
-        // nothing
-    } else {
-        writer.write_u8(0xFF)?;
-    }
-
-    write_packet_len(len, writer)
-}
-
-/// Write the raw packet length.
-pub fn write_packet_len(len: usize, writer: &mut impl io::Write) -> errors::Result<()> {
     if len < 192 {
         writer.write_u8(len.try_into()?)?;
     } else if len < 8384 {
         writer.write_u8((((len - 192) / 256) + 192) as u8)?;
         writer.write_u8(((len - 192) % 256) as u8)?;
     } else {
+        writer.write_u8(0xFF)?;
         writer.write_u32::<BigEndian>(len as u32)?;
     }
 
     Ok(())
 }
 
-pub fn end_of_line(input: &[u8]) -> IResult<&[u8], &[u8]> {
-    alt((eof, end_of_line))(input)
-}
-
 /// Return the length of the remaining input.
 // Adapted from https://github.com/Geal/nom/pull/684
 #[inline]
@@ -229,7 +212,7 @@ mod tests {
     #[test]
     fn test_write_packet_len() {
         let mut res = Vec::new();
-        write_packet_len(1173, &mut res).unwrap();
+        write_packet_length(1173, &mut res).unwrap();
         assert_eq!(hex::encode(res), "c3d5");
     }
 
@@ -246,4 +229,11 @@ mod tests {
         let stripped = strip_leading_zeros(&buf);
         assert_eq!(stripped, &[]);
     }
+
+    #[test]
+    fn test_strip_leading_zeros_vec() {
+        let mut vec = vec![0, 0, 0, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
+        strip_leading_zeros_vec(&mut vec);
+        assert_eq!(vec, vec![1, 2, 3, 4, 5, 6, 7, 8, 9]);
+    }
 }
